summaryrefslogtreecommitdiffstats
path: root/sfx2/qa
diff options
context:
space:
mode:
authorNoel Grandin <noel@peralex.com>2014-08-13 09:32:50 +0200
committerNoel Grandin <noel@peralex.com>2014-08-20 10:35:53 +0200
commit2922a967a1da5f9c0a07b5390906307d0ae6fe48 (patch)
treebc8d0a6f25e5d058adecb016f619096d64c4a484 /sfx2/qa
parentno need to instantiate an object to get it's class (diff)
downloadcore-2922a967a1da5f9c0a07b5390906307d0ae6fe48.tar.gz
core-2922a967a1da5f9c0a07b5390906307d0ae6fe48.zip
java: Avoid naming non-fields with the prefix m_
found by PMD Change-Id: I5955cfc9c4d777496a2e8e4b2c422a51764a8bc1
Diffstat (limited to 'sfx2/qa')
-rw-r--r--sfx2/qa/complex/sfx2/tools/WriterHelper.java6
1 files changed, 3 insertions, 3 deletions
diff --git a/sfx2/qa/complex/sfx2/tools/WriterHelper.java b/sfx2/qa/complex/sfx2/tools/WriterHelper.java
index 4b3456d59cdd..2dd6fad055a8 100644
--- a/sfx2/qa/complex/sfx2/tools/WriterHelper.java
+++ b/sfx2/qa/complex/sfx2/tools/WriterHelper.java
@@ -42,10 +42,10 @@ public class WriterHelper {
private XMultiServiceFactory m_xMSF = null;
/** Creates a new instance of WriterHelper
* @param m_xMSF The MultiServiceFactory gained from the office
*/
- public WriterHelper(XMultiServiceFactory m_xMSF) {
- this.m_xMSF = m_xMSF;
+ public WriterHelper(XMultiServiceFactory xMSF) {
+ this.m_xMSF = xMSF;
}
/** Opens an empty document
@@ -42,10 +42,10 @@ public class WriterHelper {
private XMultiServiceFactory m_xMSF = null;
/** Creates a new instance of WriterHelper
- * @param m_xMSF The MultiServiceFactory gained from the office
+ * @param xMSF The MultiServiceFactory gained from the office
*/